==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/es-MX/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Activo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Equipos',
    'created_at' 			=> 'Creado',
    'createuser' 			=> 'Crear Usuario',
    'deny'  				=> 'Denegar',
    'email'      			=> 'Correo electrónico',
    'employee_num'      	=> 'No. Empleado',
    'first_name' 			=> 'Nombre',
    'groupnotes'			=> 'Seleccione un grupo para asignar al usuario, recuerde que un usuario asume los permisos del grupo al que se le asigna. Use ctrl+click (o cmd+click en MacOS) para anular la selección de grupos.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Hereda de',
    'job' 					=> 'Cargo',
    'last_login'  			=> 'Ultimo Login',
    'last_name'  			=> 'Apellidos',
    'location'  			=> 'Ubicación',
    'lock_passwords'		=> 'Los detalles de acceso no pueden ser cambiados en esta instalación.',
    'manager' 				=> 'Supervisor',
    'managed_locations'     => 'Ubicaciones gestionadas',
    'managed_users'         => 'Usuarios gestionados',
    'name' 					=> 'Nombre',
    'nogroup'               => 'Aún no se han creado grupos. Para añadir uno, visite: ',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar Password',
    'password' 				=> 'Contraseña',
    'phone'  				=> 'Teléfono',
    'show_current'          => 'Mostrar usuarios actuales',
    'show_deleted'          => 'Mostrar usuarios eliminados',
    'title' 				=> 'Cargo',
	'to_restore_them'		=> 'para restaurarlos.',
    'total_assets_cost'     => "Coste total de activos",
    'updateuser' 			=> 'Actualizar Usuario',
    'username' 				=> 'Usuario',
	'user_deleted_text' 	=> 'Este usuario ha sido marcado como eliminado.',
    'username_note' 		=> '(Esto se usa solo para la conexión con Active Directory, no para el inicio de sesión.)',
    'cloneuser'             => 'Clonar Usuario',
    'viewusers' 			=> 'Ver Usuarios',
);

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/es-MX/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Activo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Activos',
    'created_at' 			=> 'Creado',
    'createuser' 			=> 'Crear usuario',
    'deny'  				=> 'Denegar',
    'email'      			=> 'Correo electrónico',
    'employee_num'      	=> 'No. Empleado',
    'first_name' 			=> 'Nombre',
    'groupnotes'			=> 'Seleccione un grupo para asignar al usuario, recuerde que un usuario asume los permisos del grupo al que se le asigna. Use ctrl+click (o cmd+click en MacOS) para anular la selección de grupos.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Hereda de',
    'job' 					=> 'Cargo',
    'last_login'  			=> 'Último inicio de sesión',
    'last_name'  			=> 'Apellidos',
    'location'  			=> 'Ubicación',
    'lock_passwords'		=> 'Los detalles de inicio de sesión no pueden ser cambiados en esta instalación.',
    'manager' 				=> 'Supervisor',
    'managed_locations'     => 'Ubicaciones gestionadas',
    'managed_users'         => 'Usuarios gestionados',
    'name' 					=> 'Nombre',
    'nogroup'               => 'Aún no se han creado grupos. Para añadir uno, visite: ',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar Password',
    'password' 				=> 'Contraseña',
    'phone'  				=> 'Teléfono',
    'show_current'          => 'Mostrar usuarios actuales',
    'show_deleted'          => 'Mostrar usuarios eliminados',
    'title' 				=> 'Cargo',
	'to_restore_them'		=> 'para restaurarlos.',
    'total_assets_cost'     => "Costo total de activos",
    'updateuser' 			=> 'Actualizar usuario',
    'username' 				=> 'Nombre de usuario',
	'user_deleted_text' 	=> 'Este usuario ha sido marcado como eliminado.',
    'username_note' 		=> '(Esto se usa solo para la conexión con Active Directory, no para el inicio de sesión.)',
    'cloneuser'             => 'Clonar usuario',
    'viewusers' 			=> 'Ver usuarios',
);
